You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by dk...@apache.org on 2011/09/19 22:38:53 UTC

svn commit: r1172807 - in /camel/branches/camel-2.8.x: ./ components/camel-jetty/src/main/java/org/apache/camel/component/jetty/JettyHttpComponent.java

Author: dkulp
Date: Mon Sep 19 20:38:53 2011
New Revision: 1172807

URL: http://svn.apache.org/viewvc?rev=1172807&view=rev
Log:
Merged revisions 1157534 via svnmerge from 
https://svn.apache.org/repos/asf/camel/trunk

........
  r1157534 | davsclaus | 2011-08-14 09:58:04 -0400 (Sun, 14 Aug 2011) | 1 line
  
  Indicate in thread names from JettyHttpComponent they are from this component, to differentiate them with other Jetty usages in the JVM.
........

Modified:
    camel/branches/camel-2.8.x/   (props changed)
    camel/branches/camel-2.8.x/components/camel-jetty/src/main/java/org/apache/camel/component/jetty/JettyHttpComponent.java

Propchange: camel/branches/camel-2.8.x/
------------------------------------------------------------------------------
Binary property 'svnmerge-integrated' - no diff available.

Modified: camel/branches/camel-2.8.x/components/camel-jetty/src/main/java/org/apache/camel/component/jetty/JettyHttpComponent.java
URL: http://svn.apache.org/viewvc/camel/branches/camel-2.8.x/components/camel-jetty/src/main/java/org/apache/camel/component/jetty/JettyHttpComponent.java?rev=1172807&r1=1172806&r2=1172807&view=diff
==============================================================================
--- camel/branches/camel-2.8.x/components/camel-jetty/src/main/java/org/apache/camel/component/jetty/JettyHttpComponent.java (original)
+++ camel/branches/camel-2.8.x/components/camel-jetty/src/main/java/org/apache/camel/component/jetty/JettyHttpComponent.java Mon Sep 19 20:38:53 2011
@@ -592,8 +592,8 @@ public class JettyHttpComponent extends 
             if (httpClientMaxThreads != null) {
                 qtp.setMaxThreads(httpClientMaxThreads.intValue());
             }
-            // let the thread names indicate they are from this component
-            qtp.setName("CamelJetty(" + ObjectHelper.getIdentityHashCode(this) + ")");
+            // let the thread names indicate they are from the client
+            qtp.setName("CamelJettyClient(" + ObjectHelper.getIdentityHashCode(httpClient) + ")");
             try {
                 qtp.start();
             } catch (Exception e) {
@@ -830,6 +830,8 @@ public class JettyHttpComponent extends 
             if (maxThreads != null) {
                 qtp.setMaxThreads(maxThreads.intValue());
             }
+            // let the thread names indicate they are from the server
+            qtp.setName("CamelJettyServer(" + ObjectHelper.getIdentityHashCode(server) + ")");
             try {
                 qtp.start();
             } catch (Exception e) {